# HISTORY

0.3.0 Added support for APIStar version >= 0.4.0

0.2.1 Pinned APIStar requirement to 0.3.9

APIStar 0.4.0 introduced breaking changes to the framework. Since Components have completely changed we are pinning the requirement for this release.
